summaryrefslogtreecommitdiff
path: root/src/theory/theory_engine.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/theory_engine.cpp')
-rw-r--r--src/theory/theory_engine.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/theory/theory_engine.cpp b/src/theory/theory_engine.cpp
index 91d6beead..2950ad413 100644
--- a/src/theory/theory_engine.cpp
+++ b/src/theory/theory_engine.cpp
@@ -575,8 +575,10 @@ void TheoryEngine::assertFact(TNode node)
// Get the atom
TNode atom = node.getKind() == kind::NOT ? node[0] : node;
- // Assert the fact to the apropriate theory
- theoryOf(atom)->assertFact(node, true);
+ // Assert the fact to the appropriate theory and mark it active
+ Theory* theory = theoryOf(atom);
+ theory->assertFact(node, true);
+ markActive(Theory::setInsert(theory->getId()));
// If any shared terms, notify the theories
if (d_sharedTerms.hasSharedTerms(atom)) {
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback